@@ -18,7 +18,7 @@ use models::*;
 ///
 /// ```rust
 /// /// Description of the command line tool
-/// #[fncmd]
+/// #[fncmd::fncmd]
 /// pub fn main(
 ///   /// Argument foo
 ///   #[opt(short, long)]
@@ -74,7 +74,11 @@ pub fn fncmd(attr: TokenStream, item: TokenStream) -> TokenStream {
 							&& function
 								.attrs
 								.iter()
-								.any(|attr| attr.path.is_ident("fncmd"))
+								.any(|attr| {
+									// `#[fncmd::fncmd]` or `#[fncmd]`
+									attr.path.segments.len() <= 2
+									&& attr.path.segments.iter().all(|segment| segment.ident == "fncmd")
+								})
 					})
 					// If none of them are valid, just skip the file
 					.map(|function| {
